# pynorare
Python package for the NoRaRe collection

[![Build Status](https://github.com/concepticon/pynorare/workflows/tests/badge.svg)](https://github.com/concepticon/pynorare/actions?query=workflow%3Atests)
[![codecov](https://codecov.io/gh/concepticon/pynorare/branch/master/graph/badge.svg)](https://codecov.io/gh/concepticon/pynorare)
[![PyPI](https://img.shields.io/pypi/v/pynorare.svg)](https://pypi.org/project/pynorare)

